<?php

namespace Litecms\Slider\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litecms\Slider\Interfaces\SliderRepositoryInterface;
use Litecms\Slider\Repositories\Eloquent\Filters\SliderPublicFilter;
use Litecms\Slider\Repositories\Eloquent\Presenters\SliderListPresenter;

class SliderPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        SliderRepositoryInterface $slider
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litecms.slider.modules'), 'slider', guard_url('slider'));
        $this->repository = $slider;
    }

    /**
     * Show slider's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(SliderPublicFilter::class)
            ->setPresenter(SliderListPresenter::class)
            ->select('sliders.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('slider::slider.names'))
            ->view('slider::public.slider.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show slider.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('slider::slider.name'))
            ->view('slider::public.slider.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
